# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-03-30 12:52
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('collector', '0007_loggerindex_num_processes'),
    ]

    operations = [
        migrations.AddField(
            model_name='loggercolumn',
            name='indexed',
            field=models.BooleanField(default=False),
        ),
    ]
