{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
<head>
    {% block head %}
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">

        <meta name="description" content="">
        <meta name="author" content="">
        <title>{% block title %}{% endblock %}</title>
        <link rel="stylesheet" type="text/css" href="{% static 'css/lib/bootstrap.min.css' %}" />
        <script src="{% static 'js/lib/jquery.min.js' %}"></script>
        <script src="{% static 'js/lib/bootstrap.min.js' %}"></script>
        <script src="{% static 'js/lib/underscore-min.js' %}"></script>
        <script src="{% static 'js/lib/backbone-min.js' %}"></script>
        {% block extrahead %}{% endblock %}
    {% endblock %}
</head>

<body>
{% block navigation %}
<nav class="navbar navbar-inverse">
    <div class="container">
        <div class="navbar-header">
            <a class="navbar-brand" href="/">ALCO</a>
        </div>
        <div id="navbar" class="collapse navbar-collapse">
            <ul class="nav navbar-nav">
                {% block nav_items %}{% endblock %}
            </ul>
        </div>
        <!--/.nav-collapse -->
    </div>
</nav>
{% endblock %}
<div class="container-fluid">
{% block content %}
    <div>
        <h1>Autonomous Log Collector and Observer</h1>

        <p class="lead">
            Use ALCO for collecting logs from all your projects in one place,
            browse and search them online.
        </p>
    </div>
{% endblock %}
</div>
{% block footer %}
{% endblock %}
</body>
</html>
