# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-03-16 10:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('collector', '0005_loggerindex_durable'),
    ]

    operations = [
        migrations.AlterField(
            model_name='loggerindex',
            name='routing_key',
            field=models.TextField(default=b'logstash'),
        ),
    ]
